@@ -15,9 +15,24 @@ EOS
    exit(-1)
 end
 
-if (enable_config('opendap',true) && xsystem("opendap-config --libs"))
+if xsystem("ncdap-config --libs")
+  libncdods = "nc-dap"
+  cflags = `ncdap-config --cflags`.gsub(/\n/, " ")
+  libs = `ncdap-config --libs`.gsub(/\n/, " ")
+  prefix_dods = `ncdap-config --prefix`.gsub(/\n/, "")
+elsif xsystem("opendap-config --libs")
+  libncdods = "nc-dods"
+  cflags = `opendap-config --cflags`.gsub(/\n/, " ")
+  libs = `opendap-config --libs-nc`.gsub(/\n/, " ")
+  prefix_dods = `opendap-config --prefix`.gsub(/\n/, "")
+end
 
-  if (!have_library("nc-dods"))
+if (enable_config('opendap',true) && ( xsystem("opendap-config --libs")) ||
+                                       xsystem("ncdap-config --libs") )
+
+  dir_config(libncdods,prefix_dods)
+
+  if (!have_library(libncdods))
     print <<-EOS
     ** ERROR ** Library not found: nc-dods (OPeNDAP/DODS-enabled NetCDF lib)
     Install it, or run extconf.rb with option --disable-opendap.
@@ -35,8 +50,6 @@ if (enable_config('opendap',true) && xsystem("opendap-config --libs"))
     EOS
   end
 
-  cflags = `opendap-config --cflags`.gsub(/\n/, " ")
-  libs = `opendap-config --libs-nc`.gsub(/\n/, " ")
   $CFLAGS += ' '+cflags
   $LOCAL_LIBS += ' ' + libs
 
